RHUMC
=====

Mathematics Conference Scheduling Software for Rose-Hulman

The master branch is the latest release. Nightlies can be found in other branches. For stable and beta releases see [here](https://github.com/crawfonw/RHUMC/releases).

See the [wiki](https://github.com/crawfonw/RHUMC/wiki) for installation info and more.
